from MoralisSDK import api
from time import sleep
if __name__ == '__main__':
    t = api.MoralisApi()
    t.set_api_key('L1aTPccpZTZpCTcRCMyCinajCny6uIMKKYT7we5L9ReQ7cSd53jm4npzQoE0NgkW')
    nft = t.get_nfts(address='0x260fCF88102fB038B2506dC60fc49270199e12fE')
    print(nft)
    ntf_trans = t.get_nfts_transfer(address='0x260fCF88102fB038B2506dC60fc49270199e12fE')
    print(ntf_trans)
    res = t.get_nfts_token(chain='eth',address='0x260fCF88102fB038B2506dC60fc49270199e12fE',
                           token_address='0xd07dc4262bcdbf85190c01c996b4c06a461d2430',limit=3)
    print(res)
    lowest = t.get_nft_lowest_price(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d',days=5)
    print(lowest)
    transfer = t.get_nfts_transfer_blocks(from_block='12895140')
    print(transfer)
    token = t.get_token_id(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d',total_range=2)
    print(token)
    owners = t.get_nft_owners(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d',limit=1)
    print(owners)
    contract_trasfers = t.get_contract_nft_transfers(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d')
    print(contract_trasfers)
    sleep(10)
    resync = t.get_nft_metadata_resync(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d',token_id='430')
    print(resync)
    token_meta = t.get_token_id_metadata(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d',token_id='430')
    print(token_meta)
    token_owners = t.get_token_id_owners(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d',token_id='432')
    print(token_owners)
    token_trans = t.get_token_id_transfers(address='0x73f1780cb2b5ce961601fdf6a9b002082bb82b4d',token_id='430')
    print(token_trans)

# See PyCharm help at https://www.jetbrains.com/help/pycharm/



import requests
import datetime

QueryParameter = ['?', '&']


class MoralisApi:
    def __init__(self):
        self.url_base = 'https://deep-index.moralis.io/api/v2/'
        self.api_key = None

    def set_api_key(self, api_key):
        self.api_key = api_key

    def api_request(self, endpoint, method="GET", request_data=None):
        try:
            headers = {
                "x-api-key": self.api_key
            }
            response = requests.request(url=self.url_base + endpoint, method=method, headers=headers, data=request_data)
            if response.status_code == 200:
                response_object = response.json()
                # response_object['status_code'] = 200
                return response_object
            elif response.status_code == 404:
                return f'{self.url_base}{endpoint} is not found'
            else:
                return response.json()
        except Exception as err:
            print(f'Got Exception :{err}')

    def get_nfts(self, address, chain=None, token_format='decimal', limit=None, token_addresses=None, cursor=None):
        endpoint = ''
        if address:
            if type(address) == str and len(address):
                endpoint = f'{address}/nft?token_format={token_format}'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'

            if token_addresses is not None:
                if type(token_addresses) != list:
                    print('token_format Argument Type Error')
                    return TypeError('Argument Type Error: token_addresses must be list')
                for k in token_addresses:
                    endpoint += f'&token_addresses={k}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
        else:
            print('Required argument missing either address')
            return TypeError('Argument Type Error: address must be str')

        response = self.api_request(endpoint)
        return response

    def get_nfts_transfer(self, address, chain=None, token_format='decimal', limit=None, direction=None,
                          from_block=None,
                          to_block=None, cursor=None):
        endpoint = ''
        if address:
            if type(address) == str and len(address):
                endpoint = f'{address}/nft/transfers?format={token_format}'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'
            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'

            if direction is not None:
                if type(direction) != str and direction not in ['both', 'to', 'from']:
                    print('direction Argument Type Error or Invalid value')
                    return TypeError('Argument Type Error: direction must be str')
                endpoint += f'&direction={direction}'
            if from_block is not None:
                if type(from_block) != str:
                    print('from_block Argument Type Error')
                    return TypeError('Argument Type Error: from_block must be str')
                endpoint += f'&from_block={from_block}'
            if to_block is not None:
                if type(to_block) != str:
                    print('to_block Argument Type Error')
                    return TypeError('Argument Type Error: to_block must be str')
                endpoint += f'&to_block={to_block}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'

        else:
            print('Required argument missing either address')
            return TypeError('Argument Type Error: address must be str')

        response = self.api_request(endpoint)
        return response

    def get_nfts_token(self, address, chain=None, token_format='decimal', limit=None, token_address=None, cursor=None):
        endpoint = ''
        if address and token_address:
            if type(address) == str and len(address):
                if type(token_address) == str and len(token_address):
                    endpoint = f'{address}/nft/{token_address}?format={token_format}'
                else:
                    print('token_address Argument Type Error')
                    return TypeError('Argument Type Error: token_address must be str')
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')

            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'

            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
        else:
            print('Required argument missing either token_address or address')
            return TypeError('Argument Type Error: address and token_address must be str')
        response = self.api_request(endpoint)
        return response

    def get_nfts_trades(self, address, chain=None, limit=None, from_block=None,
                        to_block=None, from_date=None, to_date=None, provider_url=None, marketplace='opensea',
                        cursor=None):
        endpoint = ''
        if address:
            if type(address) == str and len(address):
                endpoint = f'nft/{address}/trades?marketplace={marketplace}'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'

            if from_block is not None:
                if type(from_block) != str:
                    print('from_block Argument Type Error')
                    return TypeError('Argument Type Error: from_block must be str')
                endpoint += f'&from_block={from_block}'
            if to_block is not None:
                if type(to_block) != str:
                    print('to_block Argument Type Error')
                    return TypeError('Argument Type Error: to_block must be str')
                endpoint += f'&to_block={to_block}'
            if from_date is not None:
                if type(from_date) != str:
                    print('from_date Argument Type Error')
                    return TypeError('Argument Type Error: from_date must be str')
                endpoint += f'&from_date={from_date}'
            if to_date is not None:
                if type(to_date) != str:
                    print('to_date Argument Type Error')
                    return TypeError('Argument Type Error: to_date must be str')
                endpoint += f'&to_date={to_date}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
            if provider_url is not None:
                if type(provider_url) != str:
                    print('provider_url Argument Type Error')
                    return TypeError('Argument Type Error: provider_url must be str')
                provider_url += f'&provider_url={provider_url}'
        else:
            print('Required argument missing address')
            return TypeError('Argument Type Error: address must be str')

        response = self.api_request(endpoint)
        return response

    def get_nft_lowest_price(self, address, chain=None, days=None, provider_url=None, marketplace='opensea'):
        endpoint = ''
        if address:
            if type(address) == str and len(address):
                endpoint = f'nft/{address}/lowestprice?marketplace={marketplace}'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'
            if days is not None:
                if type(days) != int:
                    print('days Argument Type Error')
                    return TypeError('Argument Type Error: days must be str')
                endpoint += f'&days={days}'
            if provider_url is not None:
                if type(provider_url) != str:
                    print('provider_url Argument Type Error')
                    return TypeError('Argument Type Error: provider_url must be str')
                provider_url += f'&provider_url={provider_url}'
        else:
            print('Required argument missing address')
            return TypeError('Argument Type Error: address must be str')
        print(endpoint)
        response = self.api_request(endpoint)
        return response

    def get_nfts_transfer_blocks(self, chain=None, token_format='decimal', limit=None, from_block=None, to_block=None,
                                 from_date=None, to_date=None, cursor=None):
        endpoint = f'nft/transfers?format={token_format}'
        if chain is not None:
            if type(chain) != str:
                print('chain Argument Type Error')
                return TypeError('Argument Type Error: chain must be str')
            endpoint += f'&chain={chain}'
        if limit is not None:
            if type(limit) != int:
                print('limit Argument Type Error')
                return TypeError('Argument Type Error: limit must be int')
            endpoint += f'&limit={limit}'

        if from_block is not None:
            if type(from_block) != str:
                print('from_block Argument Type Error')
                return TypeError('Argument Type Error: from_block must be str')
            endpoint += f'&from_block={from_block}'
        if to_block is not None:
            if type(to_block) != str:
                print('to_block Argument Type Error')
                return TypeError('Argument Type Error: to_block must be str')
            endpoint += f'&to_block={to_block}'
        if from_date is not None:
            if type(from_date) != str :
                print('from_date Argument Type Error')
                return TypeError('Argument Type Error: from_date must be str')
            endpoint += f'&from_date={from_date}'
        if to_date is not None:
            if type(to_date) != str:
                print('to_date Argument Type Error')
                return TypeError('Argument Type Error: to_date must be str')
            endpoint += f'&to_date={to_date}'
        if cursor is not None:
            if type(cursor) != str:
                print('cursor Argument Type Error')
                return TypeError('Argument Type Error: cursor must be str')
            endpoint += f'&cursor={cursor}'

        response = self.api_request(endpoint)
        return response

    def get_token_id(self, address, chain=None, token_format='decimal', limit=None, total_range=None, subrange=None,
                     cursor=None):
        endpoint = ''
        if address:
            if type(address) == str and len(address):
                endpoint = f'nft/{address}?token_format={token_format}'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'

            if total_range is not None:
                if type(total_range) != int:
                    print('total_range Argument Type Error')
                    return TypeError('Argument Type Error: total_range must be int')
                endpoint += f'&total_range={total_range}'
            if subrange is not None:
                if type(subrange) != int:
                    print('range Argument Type Error')
                    return TypeError('Argument Type Error: subrange must be int')
                endpoint += f'&range={subrange}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
        else:
            print('Required argument missing address')
            return TypeError('Argument Type Error: address must be str')

        response = self.api_request(endpoint)
        return response

    def get_nft_owners(self, address, chain=None, token_format='decimal', limit=None, cursor=None):
        endpoint = ''
        if address:
            if type(address) == str and len(address):
                endpoint = f'nft/{address}/owners?token_format={token_format}'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
        else:
            print('Required argument missing address')
            return TypeError('Argument Type Error: address must be str')

        response = self.api_request(endpoint)
        return response

    def get_contract_nft_transfers(self, address, chain=None, token_format='decimal', limit=None, cursor=None):
        endpoint = ''
        if address:
            if type(address) == str:
                endpoint = f'nft/{address}/transfers?token_format={token_format}'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
        else:
            print('Required argument missing address')
            return TypeError('Argument Type Error: address must be str')

        response = self.api_request(endpoint)
        return response

    def get_nft_metadata(self, address, chain=None):
        endpoint = ''
        if address:
            if type(address) == str and len(address):
                endpoint = f'nft/{address}/metadata'
            else:
                print('address Argument Type Error')
                return TypeError('Argument Type Error: address must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'
        else:
            print('Required argument missing address')
            return TypeError('Argument Type Error: address must be str')

        response = self.api_request(endpoint)
        return response

    def get_nft_metadata_resync(self, address, token_id, chain=None, flag='uri', mode='sync'):
        endpoint = ''
        if address and token_id:
            if type(token_id) == str and len(token_id):
                if type(address) == str and len(address):
                    if type(mode) == str and type(flag) == str:
                        endpoint = f'nft/{address}/{token_id}/metadata/resync?mode={mode}&flag={flag}'
                    else:
                        print('mode or flag type error')
                else:
                    print('address Argument Type Error')
                    return TypeError('Argument Type Error: address must be str')
            else:
                print('token_id Argument Type Error')
                return TypeError('Argument Type Error: token_id must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

        else:
            print('Required argument missing either token_id or address')
            return TypeError('Argument Type Error: address and token_id must be str')

        response = self.api_request(endpoint)
        return response

    def get_token_id_metadata(self, address, token_id, chain=None, token_format='decimal'):
        endpoint = ''
        if address and token_id:
            if type(token_id) == str and len(token_id):
                if type(address) == str and len(address):
                    if type(token_format) == str:
                        endpoint = f'nft/{address}/{token_id}?format={token_format}'
                    else:
                        print('token format type error')
                else:
                    print('address Argument Type Error')
                    return TypeError('Argument Type Error: address must be str')
            else:
                print('token_id Argument Type Error')
                return TypeError('Argument Type Error: token_id must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'

        else:
            print('Required argument missing either token_id or address')
            return TypeError('Argument Type Error: address/token_id must be str')

        response = self.api_request(endpoint)
        return response

    def get_token_id_owners(self, address, token_id, chain=None, token_format='decimal', limit=None, cursor=None):
        endpoint = ''
        if address and token_id:
            if type(token_id) == str and len(token_id):
                if type(address) == str and len(address):
                    if type(token_format) == str:
                        endpoint = f'nft/{address}/{token_id}/owners?format={token_format}'
                    else:
                        print('token format type error')
                else:
                    print('address Argument Type Error')
                    return TypeError('Argument Type Error: address must be str')
            else:
                print('token_id Argument Type Error')
                return TypeError('Argument Type Error: token_id must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'

        else:
            print('Required argument missing either token_id or address')
            return TypeError('Argument Type Error: token_id/address must be str')

        response = self.api_request(endpoint)
        return response

    def get_token_id_transfers(self, address, token_id, chain=None, order=None, token_format='decimal', limit=None,
                               cursor=None):
        endpoint = ''
        if address and token_id:
            if type(token_id) == str and len(token_id):
                if type(address) == str and len(address):
                    if type(token_format) == str:
                        endpoint = f'nft/{address}/{token_id}/transfers?format={token_format}'
                    else:
                        print('token format type error')
                else:
                    print('address Argument Type Error')
                    return TypeError('Argument Type Error: address must be str')
            else:
                print('token_id Argument Type Error')
                return TypeError('Argument Type Error: token_id must be str')
            if chain is not None:
                if type(chain) != str:
                    print('chain Argument Type Error')
                    return TypeError('Argument Type Error: chain must be str')
                endpoint += f'&chain={chain}'
            if cursor is not None:
                if type(cursor) != str:
                    print('cursor Argument Type Error')
                    return TypeError('Argument Type Error: cursor must be str')
                endpoint += f'&cursor={cursor}'
            if limit is not None:
                if type(limit) != int:
                    print('limit Argument Type Error')
                    return TypeError('Argument Type Error: limit must be int')
                endpoint += f'&limit={limit}'
            if order is not None:
                if type(order) != str:
                    print('order Argument Type Error')
                    return TypeError('Argument Type Error: order must be str')
                endpoint += f'&order={order}'

        else:
            print('Required argument missing either token_id address')
            return TypeError('Argument Type Error: address/token_id must be str')

        response = self.api_request(endpoint)
        return response
    
    def ipfs_uploadFolder(self,data):
        endpoint = 'ipfs/uploadFolder'
        headers_to_add = {"Content-Type": "application/json",
                "accept": "application/json"}
        resp = self.api_request(endpoint,method='POST',data=data,headers_to_add=headers_to_add)
        return resp

    def get_native_balance(self, wallet_address, chain):
        endpoint = wallet_address + "/balance?chain=" + chain
        response = self.api_request(endpoint)
        return float(response['balance'])

    def get_tokens_for_wallet(self, wallet_address, chain):
        endpoint = wallet_address + "/erc20?chain=" + chain
        return self.api_request(endpoint)

    def get_token_price(self, token_address, chain):
        endpoint = 'erc20/' + token_address + "/price?chain=" + chain
        return self.api_request(endpoint)

    def convert_native_amount_to_token_amount(self, token_address, chain, native_price_amount):
        price_api_response = self.get_token_price(token_address, chain)
        native_price = float(price_api_response['nativePrice']['value']) * (
                    10 ** float(-price_api_response['nativePrice']['decimals']))
        native_amount = (1 / native_price) * native_price_amount
        return native_amount

    def convert_token_amount_to_native_amount(self, token_address, chain, token_amount):
        price_api_response = self.get_token_price(token_address, chain)
        native_price = float(price_api_response['nativePrice']['value']) * (
                    10 ** float(-price_api_response['nativePrice']['decimals']))
        token_amount = (native_price) * token_amount
        return token_amount


import time
from urllib import response
from pinatapy import PinataPy
import nft_storage
from nft_storage.api import nft_storage_api
from nft_storage.model.error_response import ErrorResponse
from nft_storage.model.upload_response import UploadResponse
from nft_storage.model.unauthorized_error_response import UnauthorizedErrorResponse
from nft_storage.model.forbidden_error_response import ForbiddenErrorResponse
from pprint import pprint
import requests



class IPFS:
    def __init__(self):
        pass

    def upload_nft_storage(apikey,file):
         # See configuration.py for a list of all supported configuration parameters.
        configuration = nft_storage.Configuration(
            host = "https://api.nft.storage"
        )

        configuration = nft_storage.Configuration(
        access_token = apikey
    )
        with nft_storage.ApiClient(configuration) as api_client:
        # Create an instance of the API class
            api_instance = nft_storage_api.NFTStorageAPI(api_client)
            body = open(file, 'rb') # file_type | 

            # example passing only required values which don't have defaults set
            try:
                # Store a file
                api_response = api_instance.store(body, _check_return_type=False)
                return(api_response)
            except nft_storage.ApiException as e:
                return("Exception when calling NFTStorageAPI->store: %s\n" % e)


    def status_nft_storage(apikey,cid_):
        configuration = nft_storage.Configuration(
        host = "https://api.nft.storage"
    )
        configuration = nft_storage.Configuration(
            access_token = apikey
        )


        with nft_storage.ApiClient(configuration) as api_client:
            # Create an instance of the API class
            api_instance = nft_storage_api.NFTStorageAPI(api_client)
            cid = cid_ # str | CID for the NFT

            # example passing only required values which don't have defaults set
            try:
                # Get information for the stored file CID
                api_response = api_instance.status(cid,_check_return_type=False)
                return(api_response)
            except nft_storage.ApiException as e:
                return("Exception when calling NFTStorageAPI->status: %s\n" % e)

    def upload_web3_storage(apikey,file):

        body = open(file, 'rb')
        response = requests.post(
            "https://api.web3.storage/upload",
            headers={"Authorization": f'Bearer {apikey}'},
            files={"file": body}
        )

        return(response.json())

    def status_web3_storage(apikey,cid_):

        response = requests.get(f'https://api.web3.storage/status/{cid_}')
        return response.json()

    def nft_storage_download_link(cid_):
        data = f'https://nftstorage.link/ipfs/{cid_}'
        return data

    def web3_storage_download_link(cid_):
        data = f'https://{cid_}.ipfs.w3s.link/'
        return data

    
    def upload_pinata(pinata_api_key,pinata_secret_api_key, file):
        body = open(file, 'rb')
        pinata = PinataPy(pinata_api_key,pinata_secret_api_key)
        result = pinata.pin_file_to_ipfs(body)
        return result.json()


from setuptools import setup, find_packages

setup(
    name='MoralisSDK',
    version='1.0.2',
    packages=find_packages(exclude=['tests*']),
    license='GNU General Public License v3.0',
    description='A python wrapper for the Molaris REST API',
    long_description=open('README.md').read(),
    install_requires=[
        'requests',
    ],
    url='https://github.com/kbm9696/MoralisSDK',
    author='Balamurugan',
    author_email='kbala007.1996@gmail.com',
    long_description_content_type='text/markdown'
)



from colorama import Cursor
import requests
import sqlite3



class Chainlink:
    def __init__(self):
        pass
    
    def db_connect(self):
        sqliteConnection = sqlite3.connect('chainlink.db')
        cursor = sqliteConnection.cursor()
        return cursor

    def active_feeds(self,limit):
        cursor = self.db_connect()
        query = f'select * from Chainlink_Active_Feeds limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def Active_Feeds_Requesters(self,limit):
        cursor = self.db_connect()
        query = f'select * from Chainlink_Active_Feeds_Requesters limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def Keepers_BSC_Daily(self,limit):
        cursor = self.db_connect()
        query = f'select * from Chainlink_Keepers_BSC_Daily limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data

    def Keepers_ETH_Daily(self,limit):
        cursor = self.db_connect()
        query = f'select * from Chainlink_Keepers_ETH_Daily limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def Keepers_POLYGON_Daily(self,limit):
        cursor = self.db_connect()
        query = f'select * from Chainlink_Keepers_POLYGON_Daily limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def Oracle_Requests_over_Time(self,limit):
        cursor = self.db_connect()
        query = f'select * from Chainlink_Oracle_Requests_over_Time limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def Total_LINK_on_centralized_exchanges(self,limit):
        cursor = self.db_connect()
        query = f'select * from Total_LINK_on_centralized_exchanges limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data

    def chainlink_VRF_v1_daily_BSC(self,limit):
        cursor = self.db_connect()
        query = f'select * from chainlink_VRF_v1_daily_BSC limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def chainlink_VRF_v1_daily_ETH(self,limit):
        cursor = self.db_connect()
        query = f'select * from chainlink_VRF_v1_daily_ETH limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def chainlink_VRF_v1_daily_POLYGON(self,limit):
        cursor = self.db_connect()
        query = f'select * from chainlink_VRF_v1_daily_POLYGON limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def chainlink_VRF_v2_daily_BSC(self,limit):
        cursor = self.db_connect()
        query = f'select * from chainlink_VRF_v2_daily_BSC limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def chainlink_VRF_v2_daily_ETH(self,limit):
        cursor = self.db_connect()
        query = f'select * from chainlink_VRF_v2_daily_ETH limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data
    
    def chainlink_VRF_v2_daily_POLYGON(self,limit):
        cursor = self.db_connect()
        query = f'select * from chainlink_VRF_v2_daily_POLYGON limit {limit}'
        data = cursor.execute(query)
        data = cursor.fetchall()
        return data


    


    

